@@ -6,8 +6,8 @@
 """
 
 __author__ = "James Turk <jturk@sunlightfoundation.com>"
-__version__ = "0.3.2"
-__copyright__ = "Copyright (c) 2009 Sunlight Labs"
+__version__ = "0.3.3"
+__copyright__ = "Copyright (c) 2012 Sunlight Labs"
 __license__ = "BSD"
 
 import urllib, urllib2
@@ -534,7 +534,7 @@ class votesmart(object):
             return SigDetail(result['sig'])
 
         @staticmethod
-        def getCandidateRating(candidateId, sigId):
+        def getCandidateRating(candidateId, sigId=None):
             params = {'candidateId':candidateId, 'sigId':sigId}
             result = votesmart._apicall('Rating.getCandidateRating', params)
             return _result_to_obj(Rating, result['candidateRating']['rating'])
@@ -607,9 +607,15 @@ class votesmart(object):
             return _result_to_obj(Bill, result['bills']['bill'])
 
         @staticmethod
-        def getBillsByCandidateCategoryOffice(candidateId, categoryId, officeId=None):
+        def getBillsByOfficial(candidateId, year, officeId=None, categoryId=None):
+            params = {'candidateId':candidateId, 'year':year, 'officeId':officeId, 'categoryId':categoryId}
+            result = votesmart._apicall('Votes.getBillsByOfficial', params)
+            return _result_to_obj(Bill, result['bills']['bill'])
+
+        @staticmethod
+        def getBillsByOfficialCategoryOffice(candidateId, categoryId, officeId=None):
             params = {'candidateId':candidateId, 'categoryId':categoryId, 'officeId':officeId}
-            result = votesmart._apicall('Votes.getBillsByCandidateCategoryOffice', params)
+            result = votesmart._apicall('Votes.getBillsByOfficialCategoryOffice', params)
             return _result_to_obj(Bill, result['bills']['bill'])
 
         @staticmethod
